pub struct LockedPropMapper<'a> { /* private fields */ }Implementations
Sourceimpl<'a> LockedPropMapper<'a>
impl<'a> LockedPropMapper<'a>
pub fn get_id(&self, prop: &str) -> Option<usize>
pub fn get_dtype(&'a self, prop_id: usize) -> Option<&'a PropType>
Sourcepub fn fast_proptype_check(
&self,
prop: &str,
dtype: PropType,
) -> Result<Option<Either<usize, usize>>, PropError>
pub fn fast_proptype_check( &self, prop: &str, dtype: PropType, ) -> Result<Option<Either<usize, usize>>, PropError>
Fast check for property type without unifying the types Returns:
Some(Either::Left(id))if the property type can be unifiedSome(Either::Right(id))if the property type is already set and no unification is neededNoneif the property type is not setErr(PropError::PropertyTypeError)if the property type cannot be unified
pub fn iter_ids_and_types( &self, ) -> impl Iterator<Item = (usize, &ArcStr, &PropType)>