pub struct WriteLockedPropMapper<'a> { /* private fields */ }Expand description
Write-locked view of a PropMapper.
Implementations
Sourceimpl<'a> WriteLockedPropMapper<'a>
impl<'a> WriteLockedPropMapper<'a>
pub fn new_id_and_dtype( &mut self, key: impl Into<ArcStr>, dtype: PropType, ) -> usize
pub fn set_id_and_dtype( &mut self, key: impl Into<ArcStr>, id: usize, dtype: PropType, )
pub fn set_dtype(&mut self, id: usize, dtype: PropType)
pub fn set_or_unify_id_and_dtype( &mut self, key: impl Into<ArcStr>, id: usize, dtype: PropType, ) -> Result<(), PropError>
pub fn set_or_unify_dtype( &mut self, id: usize, dtype: PropType, ) -> Result<(), PropError>
pub fn get_dtype(&'a self, prop_id: usize) -> Option<&'a PropType>
Sourcepub fn fast_proptype_check(
&mut self,
prop: &str,
dtype: PropType,
) -> Result<Option<Either<usize, usize>>, PropError>
pub fn fast_proptype_check( &mut self, prop: &str, dtype: PropType, ) -> Result<Option<Either<usize, usize>>, PropError>
Fast check for property type without unifying the types Returns:
Some(Either::Left(id))if the property type can be unifiedSome(Either::Right(id))if the property type is already set and no unification is neededNoneif the property type is not setErr(PropError::PropertyTypeError)if the property type cannot be unified