#[repr(transparent)]pub struct VID(pub usize);Tuple Fields
0: usizeImplementations
Sourceimpl VID
impl VID
pub fn index(&self) -> usize
pub fn as_u64(&self) -> u64
Sourcepub fn is_initialised(&self) -> bool
pub fn is_initialised(&self) -> bool
check if the VID points to a node
Sourcepub fn or_init(self, init: impl FnOnce() -> VID) -> Self
pub fn or_init(self, init: impl FnOnce() -> VID) -> Self
either return self if it is initialised, otherwise run the init closure
Sourcepub fn or_maybe_init(self, init: impl FnOnce() -> Option<VID>) -> Option<Self>
pub fn or_maybe_init(self, init: impl FnOnce() -> Option<VID>) -> Option<Self>
either return Some(self) if it is initialised, otherwise, run the init closure
Sourcepub fn into_option(self) -> Option<Self>
pub fn into_option(self) -> Option<Self>
return Some(self) if initialised, otherwise, None