Module time

Module time 

Enums

InputTime
Used to handle automatic injection of event id if not explicitly provided. In many cases, we will want different behaviour if an event id was provided or not.
ParseTimeError

Traits

AsSingleTimeInput
Single time input only refers to the i64 component of an EventTime (no event id).
IntoTime
IntoTimeWithFormat
TryIntoInputTime
TryIntoTime
TryIntoTimeNeedsEventId