pub enum InputTime {
Simple(i64),
Indexed(i64, usize),
}Expand description
Used to handle automatic injection of event id if not explicitly provided. In many cases, we will want different behaviour if an event id was provided or not.
Variants
Implementations