pub trait TryIntoTime {
// Required method
fn try_into_time(self) -> Result<EventTime, ParseTimeError>;
}Required Methods
fn try_into_time(self) -> Result<EventTime, ParseTimeError>
Implementations on Foreign Types
Sourceimpl TryIntoTime for &str
impl TryIntoTime for &str
Sourcefn try_into_time(self) -> Result<EventTime, ParseTimeError>
fn try_into_time(self) -> Result<EventTime, ParseTimeError>
Tries to parse the timestamp as RFC3339 and then as ISO 8601 with local format and all fields mandatory except for milliseconds and allows replacing the T with a space