Enums
- Input
Time - Used to handle automatic injection of event id if not explicitly provided. In many cases, we will want different behaviour if an event id was provided or not.
- Parse
Time Error
Traits
- AsSingle
Time Input - Single time input only refers to the i64 component of an EventTime (no event id).
- Into
Time - Into
Time With Format - TryInto
Input Time - TryInto
Time - TryInto
Time Needs Event Id